<?php
/**
 * Plugin admin settings page - plugin CPT support.
 *
 * @package    Genesis Layout Extras
 * @subpackage Admin Plugins
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2011-2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-layout-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.3.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.7.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Second meta box - optional: setting up the setting fields & labels.
 * For supported plugins with CPTs.
 *
 * @since 1.3.0
 *
 * @uses  post_type_exists()
 * @uses  ddw_genesis_layout_extras_option()
 * @uses  ddw_gle_save_button()
 */
function ddw_genesis_layout_extras_box_cpts() {

	/** Description - user info: Plugin generated special Custom Post Type sections */
	echo '<h4>' . __( 'Special Custom Post Type Sections', 'genesis-layout-extras' ) . '</h4>';

		echo '<p><span class="description">' . __( 'Here you can set up a <strong>default</strong> layout option for various extra archive pages generated by Custom Post Types which were set by plugins. There are only post types listed for which proper template/ layout integration for Genesis exist.', 'genesis-layout-extras' ) . ' ' . sprintf(
				__( '%1$sGenesis Default%2$s in the drop-down menus below always means the chosen default layout option in the regular <a href="%3$s">Genesis layout settings</a>.', 'genesis-layout-extras' ),
				'<code style="font-style: normal; color: #333;">',
				'</code>',
				admin_url( 'admin.php?page=genesis#genesis-theme-settings-layout' )
			) . '</span></p>';


	/** Plugin: AgentPress Listings */
	if ( post_type_exists( 'listing' ) ) {

		echo '<hr class="div" />';

		echo '<h4>' . __( 'Plugin: AgentPress Listings', 'genesis-layout-extras' ) . '</h4>';

			ddw_genesis_layout_extras_option(
				__( 'Listing Post Type Layout (archive)', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_apl_listing'
			);

			ddw_genesis_layout_extras_option(
				__( 'Listings Features Taxonomy Layout', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_apl_features'
			);

			echo '<p><span class="description">' . sprintf(
					__( 'For these settings to take any effect the %1$splugin <em>AgentPress Listings</em>%2$s needs to be installed first. &mdash; Of course, the plugin (and so the setting here) could be used with the %3$sAgentPress child theme%4$s and also with any other Genesis child theme, so this setting might come in really handy ;-).', 'genesis-layout-extras' ),
					'<a href="http://deckerweb.de/go/agentpress-listings/" target="_new" title="Plugin: AgentPress Listings ...">',
					'</a>', '<a href="http://deckerweb.de/go/genesis-agentpress-child-theme/" target="_new" title="AgentPress Genesis Child Theme ...">',
					'</a>'
				) . '</span></p>';

			ddw_gle_save_button();

	}  // end-if APL check


	/** Plugin: Genesis Media Project */
	if ( post_type_exists( 'video' ) ) {

		echo '<hr class="div" />';

		echo '<h4>' . __( 'Plugin: Genesis Media Project', 'genesis-layout-extras' ) . '</h4>';

			ddw_genesis_layout_extras_option(
				__( 'Video Post Type Layout (archive)', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_gmp_video'
			);

			ddw_genesis_layout_extras_option(
				__( 'Video SlideShows Taxonomy Layout', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_gmp_slideshow'
			);

			ddw_genesis_layout_extras_option(
				__( 'Video Categories Taxonomy Layout', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_gmp_video_category'
			);

			ddw_genesis_layout_extras_option(
				__( 'Video Tags Taxonomy Layout', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_gmp_video_tag'
			);

			echo '<p><span class="description">' . sprintf(
					__( 'For these settings to take any effect the plugin %1$s needs to be installed first.', 'genesis-layout-extras' ),
					'<a href="http://wordpress.org/plugins/genesis-media-project/" target="_new" title="' . __( 'Plugin: Genesis Media Project', 'genesis-layout-extras' ) . ' ..."><em>' . __( 'Genesis Media Project', 'genesis-layout-extras' ) . '</em></a>'
				) . '</a></span></p>';

			ddw_gle_save_button();

	}  // end-if GMP check


	/** Plugins: WooCommerce & Jigoshop */
	if ( post_type_exists( 'product' ) ) {

		echo '<hr class="div" />';

		echo '<h4>' . __( 'Plugins: WooCommerce OR Jigoshop', 'genesis-layout-extras' ) . '</h4>';

			ddw_genesis_layout_extras_option(
				__( 'Product Post Type Layout - Product Categories (all)', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_wcjs_product_cat'
			);

			ddw_genesis_layout_extras_option(
				__( 'Product Post Type Layout - Product Tags (all)', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_wcjs_product_tag'
			);

			echo '<p><span class="description">' . sprintf(
					__( 'For these settings to take any effect the plugin %1$s OR %2$s needs to be installed first.', 'genesis-layout-extras' ),
					'<a href="http://wordpress.org/plugins/woocommerce/" target="_new" title="' . __( 'Plugin: WooCommerce', 'genesis-layout-extras' ) . ' ..."><em>' . __( 'WooCommerce', 'genesis-layout-extras' ) . '</em></a>',
					'<a href="http://wordpress.org/plugins/jigoshop/" target="_new" title="' . __( 'Plugin: Jigoshop', 'genesis-layout-extras' ) . ' ..."><em>' . __( 'Jigoshop', 'genesis-layout-extras' ) . '</em></a>'
				);

			echo '<br />&raquo; WooCommerce ' . __( 'Integration plugin', 'genesis-layout-extras' ) . ': <a href="http://wordpress.org/plugins/genesis-connect-woocommerce/" target="_new" title="' . __( 'Genesis Connect for WooCommerce', 'genesis-layout-extras' ) . '">' . __( 'Genesis Connect for WooCommerce', 'genesis-layout-extras' ) . '</a>';

			echo '<br />&raquo; Jigoshop ' . __( 'Integration plugin', 'genesis-layout-extras' ) . ': <a href="http://jigoshop.com/extend/genesis-connect-for-jigoshop/" target="_new" title="' . __( 'Genesis Connect for Jigoshop', 'genesis-layout-extras' ) . '">' . __( 'Genesis Connect for Jigoshop', 'genesis-layout-extras' ) . '</a></span></p>';

			ddw_gle_save_button();

	}  // end-if CPT "product" check


	/** Plugin: Easy Digital Downloads */
	if ( post_type_exists( 'download' ) ) {

		echo '<hr class="div" />';

		echo '<h4>' . __( 'Plugin: Easy Digital Downloads', 'genesis-layout-extras' ) . '</h4>';

			ddw_genesis_layout_extras_option(
				__( 'Download Post Type Layout (archive)', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_edd_download'
			);

			ddw_genesis_layout_extras_option(
				__( 'Download Categories Taxonomy Layout', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_edd_download_category'
			);

			ddw_genesis_layout_extras_option(
				__( 'Download Tags Taxonomy Layout', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_edd_download_tag'
			);

			echo '<p><span class="description">' . sprintf(
					__( 'For these settings to take any effect the plugin %1$s needs to be installed first.', 'genesis-layout-extras' ),
					'<a href="http://wordpress.org/plugins/easy-digital-downloads/" target="_new" title="' . __( 'Plugin: Easy Digital Downloads', 'genesis-layout-extras' ) . ' ..."><em>' . __( 'Easy Digital Downloads', 'genesis-layout-extras' ) . '</em></a>'
				);

			echo '<br />&raquo; ' . __( 'Integration plugin', 'genesis-layout-extras' ) . ': <a href="http://wordpress.org/plugins/genesis-connect-edd/" target="_new" title="' . __( 'Genesis Connect for Easy Digital Downloads', 'genesis-layout-extras' ) . '">' . __( 'Genesis Connect for Easy Digital Downloads', 'genesis-layout-extras' ) . '</a></span></p>';

			ddw_gle_save_button();

	}  // end-if EDD check


	/** Plugin: Sugar Events Calendar */
	if ( post_type_exists( 'sc_event' ) ) {

		echo '<hr class="div" />';

		echo '<h4>' . __( 'Plugin: Sugar Events Calendar', 'genesis-layout-extras' ) . '</h4>';

			ddw_genesis_layout_extras_option(
				__( 'Event Post Type Layout (archive)', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_sc_event'
			);

			ddw_genesis_layout_extras_option(
				__( 'Event Categories Taxonomy Layout', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_cpt_sc_event_category'
			);

			echo '<p><span class="description">' . sprintf(
					__( 'For these settings to take any effect the plugin %1$s needs to be installed first.', 'genesis-layout-extras' ),
					'<a href="http://ddwb.me/sugarevents" target="_new" title="' . __( 'Plugin: Sugar Events Calendar', 'genesis-layout-extras' ) . ' ..."><em>' . __( 'Sugar Events Calendar', 'genesis-layout-extras' ) . '</em></a>'
				);

			ddw_gle_save_button();

	}  // end-if Sugar Events check


	/** Plugin: bbPress 2.x Forum section */
	if ( class_exists( 'bbPress' ) ) {

		echo '<hr class="div" />';

		echo '<h4>' . __( 'Plugin: bbPress 2.x Forum Section', 'genesis-layout-extras' ) . '</h4>';

			ddw_genesis_layout_extras_option(
				__( 'bbPress 2.x Forum Layout (all areas)', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_bbpress'
			);

			ddw_genesis_layout_extras_option(
				__( 'bbPress 2.x Topics Layout', 'genesis-layout-extras' ) . ': ',
				'ddw_genesis_layout_bbpress_topics'
			);

			echo '<p><span class="description">' . sprintf(
					__( 'For this setting to take any effect the plugin %1$s needs to be installed first.', 'genesis-layout-extras' ),
					'<a href="http://wordpress.org/plugins/bbpress/" target="_new" title="' . __( 'Plugin: bbPress 2.x Forum', 'genesis-layout-extras' ) . ' ..."><em>' . __( 'bbPress 2.x', 'genesis-layout-extras' ) . '</em></a>'
				);

			echo '<br />&raquo; ' . __( 'Integration plugin', 'genesis-layout-extras' ) . ': <a href="http://wordpress.org/plugins/bbpress-genesis-extend/" target="_new" title="' . __( 'bbPress Genesis Extend', 'genesis-layout-extras' ) . '">' . __( 'bbPress Genesis Extend', 'genesis-layout-extras' ) . '</a></span></p>';

			ddw_gle_save_button();

	}  // end-if bbPress check

}  // end of function ddw_genesis_layout_extras_box_cpts